#delimit ;

set memory 25000k;
use endorsements_final, clear;
save tmp1, replace;

/* LOG FILE FOR STORING RESULTS */

capture log close;
quietly log using endorsements.log, text replace;
log off;


/* FIRST, MAKE A FEW NECESSARY VARIABLES */

gen decade = int(year/10)*10;
replace decade = 1990 if decade==2000|decade==2002;
gen year4 = int(year/4)*4;
gen yearx = year;
replace yearx = year-1 if mod(year,2)==1;
gen str10 st_pid_dec = st_pid + string(decade);
gen str10 st_pid_yr  = st_pid + string(year);
gen str10 st_pid_yr4 = st_pid + string(year4);
egen first_year = min(year), by(st_pid);
replace first_year = 1940 if newspaper=="RICHMOND TIMES DISPATCH";

gen INC = D_incumb - R_incumb;
gen OTH = D_other_office - R_other_office;
gen END = D_endorsed - R_endorsed if (N_endorsed==0 | N_endorsed==2 | N_endorsed==3);

gen MADE_ENDORSEMENT = (D_endorsed==1 | R_endorsed==1 | N_endorsed==2 | N_endorsed==3);

gen     period = 1940 if (year>=1940 & year<=1955) ;
replace period = 1956 if (year>=1956 & year<=1969) ;
replace period = 1970 if (year>=1970 & year<=1985) ;
replace period = 1986 if (year>=1986 & year<=2002) ;

quietly tab year, gen(yy);
for var INC OTH:
  gen X1 = X * (period==1940) \ 
  gen X2 = X * (period==1956) \
  gen X3 = X * (period==1970) \
  gen X4 = X * (period==1986) ;
gen     period_z = 1 if (period==1940);
replace period_z = 2 if (period==1956);
replace period_z = 3 if (period==1970);
replace period_z = 4 if (period==1986);
egen NUM_DR_ENDORSEMENTS = count(END), by(st_pid_yr);

sort state newspaper first_year;


quietly log on;

/* TABLE 1.A OF APPENDIX */

list state newspaper first_year if st_pid!=st_pid[_n-1], noo nod;
quietly log off;



quietly log on;

/* FOR TABLE 1 */

replace MADE_ENDORSEMENT = MADE_ENDORSEMENT * 100;
table newspaper period if first_year==1940 & office!="H", contents(mean MADE_ENDORSEMENT) format(%5.2f);
quietly log off;
replace MADE_ENDORSEMENT = MADE_ENDORSEMENT/100;


/* REGRESSION FOR MAKING NEW FIGURE 1 (OLD FIGURE 3), AND TABLE 4 */

gen incadv = .;
areg END INC1 INC2 INC3 INC4 if first_year==1940 & NUM_DR_ENDORSEMENTS>2, a(st_pid_yr) robust;
  gen sample1 = e(sample);
  for num 1 2 3 4: replace incadv = _b[INCX] if period_z==X;
  local m = _b[_cons];
  predict A if sample1==1, d;
  replace A = A + `m';
  gen ABS_A = abs(A);
  tab period if sample1==1, sum(ABS_A);
  egen A_mean = mean(A) if sample1==1, by(yearx);
  egen partisanship = mean(ABS_A), by(period);
  label var partisanship "If Change Party";
  label var incadv       "If Change Incumbency Status";
  sort period_z partisanship;


/* NEW FIGURE 1 (OLD FIGURE 3) */

graph7 partisanship incadv period_z if partisanship!=partisanship[_n-1], c(ll) saving(figure1, replace) gap(4) 
  b1("  ") b2("Period") l1("Change in Probability of Endorsement") xlabel(1,2,3,4) ylabel(.1,.2,.3,.4,.5,.6,.7,.8);


quietly log on;

/* REGRESSIONS FOR TABLE 2 */

areg END INC1 INC2 INC3 INC4                         if first_year==1940 & NUM_DR_ENDORSEMENTS>2, a(st_pid_yr) robust;
areg END INC1 INC2 INC3 INC4 OTH1 OTH2 OTH3 OTH4     if first_year==1940 & NUM_DR_ENDORSEMENTS>2, a(st_pid_yr) robust;
areg END INC1 INC2 INC3 INC4                     yy* if first_year==1940 & NUM_DR_ENDORSEMENTS>2, a(st_pid_dec) robust;
areg END INC1 INC2 INC3 INC4 OTH1 OTH2 OTH3 OTH4 yy* if first_year==1940 & NUM_DR_ENDORSEMENTS>2, a(st_pid_dec) robust;


/* REGRESSIONS FOR TABLE 3 */

areg END INC4       if year>=1986 & NUM_DR_ENDORSEMENTS>2, a(st_pid_yr) robust;
quietly log off;
  gen sample2 = e(sample);
  local m = _b[_cons];
  predict B1 if sample2==1, d;
  replace B1 = B1 + `m';
  gen ABS_B1 = abs(B1);
  tab period if sample2==1, sum(ABS_B1);
  egen B1_mean = mean(B1) if sample2==1, by(yearx);


quietly log on;
areg END INC4 OTH4  if year>=1986 & NUM_DR_ENDORSEMENTS>2, a(st_pid_yr) robust;
quietly log off;
  gen sample3 = e(sample);
  local m = _b[_cons];
  predict B2 if sample3==1, d;
  replace B2 = B2 + `m';
  gen ABS_B2 = abs(B2);
  tab period if sample3==1, sum(ABS_B2);


quietly log on;

/* TABLE 4 */
table newspaper period if first_year==1940, contents(mean A) format(%5.2f);

quietly log close;


/* NEW FIGURE 2 */

sort year A_mean;
graph7 A_mean year if year>=1942 & mod(year,2)==0 & A_mean!=A_mean[_n-1], yline(0) c(l) xlabel(1940,1950,1960,1970,1980,1990,2000) ylabel(-.8,-.6,-.4,-.2,0,.2) gap(4)
  b1("  ") b2("Year of Election") l1("Average Propensity to Endorse Democrats") saving(figure2, replace);


/* PAPER-BY-PAPER PROPENSITY TO ENDORSE DEMOCRATS */

sort newspaper year;
graph7 A year if first_year==1940 & NUM_DR_ENDORSEMENTS>2, yline(0) xlabel(1940,1960,1980,2000) ylabel(-1,0,1) by(newspaper) c(l)
  b1("  ") b2("Year of Election") l1("Propensity to Endorse Democrats") gap(2) saving(figure2a, replace);


/* ANOTHER FIGURE, WHICH INCLUDES THE FULL SAMPLE */

label var A_mean  "Subsample of Major Newspapers";
label var B1_mean "All Newspapers in Sample";
sort year A_mean;
graph7 A_mean B1_mean year if year>=1942 & mod(year,2)==0 & A_mean!=A_mean[_n-1], yline(0) c(ll) xlabel(1940,1950,1960,1970,1980,1990,2000) ylabel(-.8,-.6,-.4,-.2,0,.2) gap(4)
  b1("  ") b2("Year of Election") l1("Average Propensity to Endorse Democrats") saving(figure2b, replace);

sort state st_pid year office dist type;

erase tmp1.dta;
